@@ -37,11 +37,11 @@
 
 #define VERLINES 7							/* number of lines in this vanity text */
 #define VER1 "## dgamelaunch - network console game launcher\n"
-#define VER2 "## version 1.2.16\n"
+#define VER2 "## version 1.2.20\n"
 #define VER3 "## \n"
 #define VER4 "## (c)2001-3 M. Drew Streib. This program's source is released under the GPL.\n"
 #define VER5 "## Send mail to <dtype@dtype.org> for details or a copy of the source code.\n"
-#define VER6 "## *Games on this server are recorded for in-progress viewing and playback!*\n"
+#define VER6 "## ** Games on this server are recorded for in-progress viewing and playback!\n"
 #define VER7 "## Server info is at http://dtype.org/nethack/"
 
 /* ************************************************************* */
@@ -71,7 +71,6 @@ extern int slave;
 extern struct termios tt;
 extern struct winsize win;
 
-
 /* global variables */
 
 int caught_sighup = 0;
@@ -167,6 +166,7 @@ catch_sighup ()
 	caught_sighup = 1;
 	if (pid_game)
 		{
+			sleep (10);
 			kill (pid_game, SIGHUP);
 			sleep (5);
 		}
