@@ -41,6 +41,7 @@
 #include <sys/stat.h>
 #include <string.h>
 
+
 #include "ttyrec.h"
 #include "io.h"
 
@@ -49,7 +50,7 @@ off_t seek_offset_clrscr;
 
 typedef double (*WaitFunc) (struct timeval prev,
 														struct timeval cur, double speed);
-typedef int (*ReadFunc) (FILE * fp, Header * h, char **buf);
+typedef int (*ReadFunc) (FILE * fp, Header * h, char **buf, int pread);
 typedef void (*WriteFunc) (char *buf, int len);
 typedef void (*ProcessFunc) (FILE * fp, double speed,
 														 ReadFunc read_func, WaitFunc wait_func);
@@ -122,8 +123,11 @@ ttynowait (struct timeval prev, struct timeval cur, double speed)
 }
 
 int
-ttyread (FILE * fp, Header * h, char **buf)
+ttyread (FILE * fp, Header * h, char **buf, int pread)
 {
+	int counter = 0;
+	long offset;
+
 	if (read_header (fp, h) == 0)
 		{
 			return 0;
@@ -135,15 +139,21 @@ ttyread (FILE * fp, Header * h, char **buf)
 			perror ("malloc");
 		}
 
-	if (fread (*buf, 1, h->len, fp) == 0)
+	offset = ftell(fp);
+	if (fread (*buf, 1, h->len, fp) < h->len)
 		{
-			perror ("fread");
+			fseek (fp, offset, SEEK_SET);
+			sleep(1);
+			if (counter++ > 10) 
+				{
+					perror ("fread");
+				}
 		}
 	return 1;
 }
 
 int
-ttypread (FILE * fp, Header * h, char **buf)
+ttypread (FILE * fp, Header * h, char **buf, int pread)
 {
 	int counter = 0;
 	fd_set readfs;
@@ -155,15 +165,18 @@ ttypread (FILE * fp, Header * h, char **buf)
 	/*
 	 * Read persistently just like tail -f.
 	 */
-	while (ttyread (fp, h, buf) == 0)
+	while (ttyread (fp, h, buf, 1) == 0)
 		{
-			struct timeval w = { 0, 250000 };
+			struct timeval w = { 0, 100000 };
 			select (0, NULL, NULL, NULL, &w);
 			clearerr (fp);
 			if (counter++ > (15 * 60 * 4))
-				return 0;
-			if (caught_sighup)
-				exit (210);
+				{
+					endwin ();
+					printf ("exiting on counter max");
+					exit (2);
+					return 0;
+				}
 
 
 			/* look for keypresses here. as good a place as any */
@@ -217,7 +230,7 @@ ttyplay (FILE * fp, double speed, ReadFunc read_func,
 			char *buf;
 			Header h;
 
-			if (read_func (fp, &h, &buf) == 0)
+			if (read_func (fp, &h, &buf, 0) == 0)
 				{
 					break;
 				}
@@ -291,7 +304,7 @@ set_seek_offset_clrscr (FILE * fp)
 			char *buf;
 			Header h;
 
-			if (ttyread (fp, &h, &buf) == 0)
+			if (ttyread (fp, &h, &buf, 0) == 0)
 				{
 					break;
 				}
